@@ -483,6 +483,7 @@ class PostExtractor:
                 logger.error(e)
                 total_photos_in_gallery -= 1
 
+        errors = 0
         while len(images) < total_photos_in_gallery:
             # More photos to fetch. Follow the left arrow link of the last image we were on
             direction = '{"tn":"+>"}'
@@ -500,6 +501,11 @@ class PostExtractor:
                 elem = response.html.find(".img[data-sigil='photo-image']", first=True)
                 descriptions.append(elem.attrs.get("alt") or elem.attrs.get("aria-label"))
                 image_ids.append(re.search(r'[=/](\d+)', url).group(1))
+            else:
+                errors += 1
+                if errors > 5:
+                    logger.error("Reached image error limit")
+                    break
         image = images[0] if images else None
         image_id = image_ids[0] if image_ids else None
         return {"image": image, "images": images, "images_description": descriptions, "image_id": image_id, "image_ids": image_ids}
@@ -635,7 +641,7 @@ class PostExtractor:
 
     def extract_video_lowres(self, video_data_element):
         try:
-            data = json.loads(video_data_element.attrs['data-store'])
+            data = json.loads(video_data_element.attrs['data-store'].replace("\\\\", "\\"))
             return {'video': data.get('src').replace("\\/", "/")}
         except JSONDecodeError as ex:
             logger.error("Error parsing data-store JSON: %r", ex)
@@ -783,9 +789,15 @@ class PostExtractor:
         else:
             date = None
 
-        image_url = comment.find('[data-sigil="comment-body"] + div a[href]', first=True)
-        if image_url and image_url.attrs["href"].startswith("https://lm.facebook.com/l.php"):
-            image_url = parse_qs(urlparse(image_url.attrs["href"]).query).get("u")
+        image_url = comment.find('a[href^="https://lm.facebook.com/l.php"]', first=True)
+        if image_url:
+            image_url = parse_qs(urlparse(image_url.attrs["href"]).query).get("u")[0]
+        else:
+            image_url = comment.find('i.img:not(.profpic)[style]', first=True)
+            if image_url:
+                match = self.image_regex_lq.search(image_url.attrs["style"])
+                if match:
+                    image_url = utils.decode_css_url(match.groups()[0])
 
         return {
             "comment_id": comment_id,
@@ -915,8 +927,8 @@ class PostExtractor:
         if self._full_post_html is not None:
             return self._full_post_html
 
-        if self.options.get("allow_extra_requests", True) and self.post.get('post_url'):
-            url = self.post.get('post_url').replace(FB_BASE_URL, FB_MOBILE_BASE_URL)
+        if self.options.get("allow_extra_requests", True) and self.post.get('post_id'):
+            url = self.post.get('post_id')
             logger.debug(f"Fetching {url}")
             response = self.request(url)
             self._full_post_html = response.html
