@@ -18,9 +18,7 @@ logger = logging.getLogger(__name__)
 
 
 def iter_pages(account: str, request_fn: RequestFunction, **kwargs) -> Iterator[Page]:
-    start_url = None
-    if "start_url" in kwargs:
-        start_url = kwargs.pop("start_url")
+    start_url = kwargs.pop("start_url", None)
     if not start_url:
         start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/posts/')
         try:
@@ -30,9 +28,13 @@ def iter_pages(account: str, request_fn: RequestFunction, **kwargs) -> Iterator[
     return generic_iter_pages(start_url, PageParser, request_fn, **kwargs)
 
 
-def iter_group_pages(group: Union[str, int], request_fn: RequestFunction) -> Iterator[Page]:
-    start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'groups/{group}/')
-    return generic_iter_pages(start_url, GroupPageParser, request_fn)
+def iter_group_pages(group: Union[str, int], request_fn: RequestFunction, **kwargs) -> Iterator[Page]:
+    start_url = kwargs.pop("start_url", None)
+
+    if not start_url:
+        start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'groups/{group}/')
+
+    return generic_iter_pages(start_url, GroupPageParser, request_fn, **kwargs)
 
 
 def iter_photos(account: str, request_fn: RequestFunction, **kwargs) -> Iterator[Page]:
